import { ObjectLocator, Rule, RuleProps } from './base';
export declare enum TransformationAction {
    ADD_COLUMN = "add-column",
    INCLUDE_COLUMN = "include-column",
    REMOVE_COLUMN = "remove-column",
    RENAME = "rename",
    CONVERT_LOWERCASE = "convert-lowercase",
    CONVERT_UPPERCASE = "convert-uppercase",
    ADD_PREFIX = "add-prefix",
    REMOVE_PREFIX = "remove-prefix",
    REPLACE_PREFIX = "replace-prefix",
    ADD_SUFFIX = "add-suffix",
    REMOVE_SUFFIX = "remove-suffix",
    REPLACE_SUFFIX = "replace-suffix",
    DEFINE_PRIMARY_KEY = "define-primary-key",
    CHANGE_DATA_TYPE = "change-data-type",
    ADD_BEFORE_IMAGE_COLUMNS = "add-before-image-columns"
}
export declare enum TransformationTarget {
    SCHEMA = "schema",
    TABLE = "table",
    COLUMN = "column",
    TABLE_TABLESPACE = "table-tablespace",
    INDEX_TABLESPACE = "index-tablespace"
}
export interface DataTypeParams {
    readonly type: string;
    readonly precision?: number;
    readonly scale?: number | string;
    readonly length?: number;
}
export interface PrimaryKeyDefinition {
    readonly name: string;
    readonly origin?: 'primary-key' | 'unique-index';
    readonly columns: string[];
}
export interface BeforeImageDefinition {
    readonly columnPrefix?: string;
    readonly columnSuffix?: string;
    readonly columnFilter: 'pk-only' | 'non-lob' | 'all';
}
export interface TransformationObjectLocator extends ObjectLocator {
    readonly tableTablespaceName?: string;
    readonly indexTablespaceName?: string;
    readonly columnName?: string;
    readonly dataType?: DataTypeParams;
}
export interface TransformationRuleProps extends RuleProps {
    readonly ruleTarget: TransformationTarget;
    readonly value?: string;
    readonly oldValue?: string;
    readonly dataType?: DataTypeParams;
    readonly expression?: string;
    readonly primaryKeyDef?: PrimaryKeyDefinition;
    readonly beforeImageDef?: BeforeImageDefinition;
    readonly objectLocator: TransformationObjectLocator;
}
export declare class TransformationRule extends Rule {
    ruleType: string;
    ruleTarget: TransformationTarget;
    value?: string;
    oldValue?: string;
    dataType?: DataTypeParams;
    expression?: string;
    primaryKeyDef?: PrimaryKeyDefinition;
    beforeImageDef?: BeforeImageDefinition;
    objectLocator: TransformationObjectLocator;
    constructor(props: TransformationRuleProps);
    format(): any;
}
