import * as dms from 'aws-cdk-lib/aws-dms';
import { Construct } from 'constructs';
import { TableMappings, TaskSettings } from './core';
import { S3SourceEndpoint, S3SourceEndpointSettings, S3TargetEndpoint, S3TargetEndpointSettings } from './endpoints';
export interface S32s3Props {
    /**
     * The arn of the S3 bucket to be used as source.
     */
    readonly sourceBucketArn: string;
    /**
     * The settings for the source s3 endpoint.
     */
    readonly sourceEndpointSettings?: S3SourceEndpointSettings;
    /**
     * The arn of the S3 bucket to be used as target.
     */
    readonly targetBucketArn: string;
    /**
     * The settings for the source s3 endpoint.
     */
    readonly targetEndpointSettings?: S3TargetEndpointSettings;
    /**
     * The table mappings to be used for the replication.
     */
    readonly tableMappings: TableMappings;
    /**
     * Optional JSON settings for AWS DMS Serverless replications.
     */
    readonly taskSettings?: TaskSettings;
}
export declare class S32s3 extends Construct {
    readonly replicationInstance: dms.CfnReplicationInstance;
    replicationTask: dms.CfnReplicationTask;
    source: S3SourceEndpoint;
    target: S3TargetEndpoint;
    constructor(scope: Construct, id: string, props: S32s3Props);
}
